@@ -3,12 +3,12 @@
 # This is a driver installer for eGalax Touch controller.
 #
 # Company: eGalax_eMPIA Technology Inc. (EETI)
-# Version: 1.04.1922
-# Released: 2009/07/22
+# Version: 1.05.3128
+# Released: 2010/07/28
 # Support: touch_fae@eeti.com
 #
 
-version="1.04.1922"
+version="1.05.3128"
 driver="eGalaxTouch.tar.gz"
 utility="eGalaxTouch"
 caltool="TKCal"
@@ -21,13 +21,17 @@ xmodulespath="/usr/X11R6/lib/modules/input"
 xmodulespath2="/usr/lib/xorg/modules/input"
 blacklistpath="/etc/modprobe.d/blacklist"
 blacklistpath2="/etc/modprobe.d/blacklist-compat" # for Mandriva 2008
-blacklistpath3="/etc/hotplug/blacklist"
+blacklistpath3="/etc/modprobe.d/blacklist.conf" # for Ubuntu 10.04
+blacklistpath4="/etc/modprobe.d/50-blacklist.conf" # for SuSE 11.2
+blacklistpath5="/etc/hotplug/blacklist"
 rclocalpath="/etc/rc.d/rc.local"
 identifier="EETI"
 paramfile="/var/lib/eeti.param"
 trash="/dev/null"
 libpath="/usr/lib/libXfixes.so.3"
 libpath2="/usr/X11R6/lib/libXfixes.so.3"
+rulefile="69-eeti_hiddev.rules"
+rulepath="/etc/udev/rules.d"
 
 ShowTitle() {
     echo ""
@@ -191,14 +195,26 @@ CheckXorgVersion() {
                     echo "(I) Check X window version: 1.6.x"
                     xdirectory="x16"
                 else
-                    grep -q "X Window System Version 6.8.99.900" ${xfile} # Mandriva 2006
+                    grep -q "X.Org X Server 1.7." ${xfile} # Fedora 12
                     if [ $? -eq 0 ]; then
-                        echo "(I) Check X window version: 6.8.99.900"
-                        xmodule="egalax_drv.o"
-                        xdirectory="x67"
+                        echo "(I) Check X window version: 1.7.x"
+                        xdirectory="x17"
                     else
-                        echo "(I) Check X window version: 6.9.0 ~ 7.2.0"
-                        xdirectory="x69"
+                        grep -q "X.Org X Server 1.8." ${xfile} # Fedora 13
+                        if [ $? -eq 0 ]; then
+                            echo "(I) Check X window version: 1.8.x"
+                            xdirectory="x18"
+                        else
+                            grep -q "X Window System Version 6.8.99.900" ${xfile} # Mandriva 2006
+                            if [ $? -eq 0 ]; then
+                                echo "(I) Check X window version: 6.8.99.900"
+                                xmodule="egalax_drv.o"
+                                xdirectory="x67"
+                            else
+                                echo "(I) Check X window version: 6.9.0 ~ 7.2.0"
+                                xdirectory="x69"
+                            fi
+                        fi
                     fi
                 fi
             fi
@@ -212,14 +228,19 @@ CopyXorgMudule() {
         mousepath=`find ${xmodulespath} -name mouse_drv.*o`
     elif [ -e ${xmodulespath2}/mouse_drv.*o ]; then
         mousepath=`find ${xmodulespath2} -name mouse_drv.*o`
+    elif [ -e ${xmodulespath2}/evdev_drv.*o ]; then # 2010/04/01
+        mousepath=`find ${xmodulespath2} -name evdev_drv.*o`
     else
         echo "(I) Searching the X input modules directory."
         mousepath=`find /usr -name mouse_drv.*o`
         if [ -z "${mousepath}" ]; then
-            RemoveDriver
-            echo "(E) No X input modules directory found."
-            echo ""
-            exit 1
+            mousepath=`find /usr -name evdev_drv.*o` # 2010/04/01
+            if [ -z "${mousepath}" ]; then
+                RemoveDriver
+                echo "(E) No X input modules directory found."
+                echo ""
+                exit 1
+            fi
         fi
     fi
 
@@ -233,6 +254,10 @@ CopyXorgMudule() {
         xdirectory="x67"
         xpath=${xmodulespath}
         echo "(I) Check X window version: 6.7 ~ 6.8.2"
+    elif [ ${mouse} = "evdev_drv.so" ]; then # 2010/04/01
+        xmodule="egalax_drv.so"
+        CheckXorgVersion
+        xpath=${mousepath%/*}
     else
         RemoveDriver
         echo "(E) Unknown mouse module!"
@@ -268,6 +293,33 @@ RemoveXorgModule() {
     echo "(I) Removed X module."
 }
 
+CheckMoblin() {
+    checkx="X -version"
+    xfile="X.info"
+    ${checkx} > ${xfile} 2>&1
+    grep -q "moblin" ${xfile}
+    if [ $? -eq 0 ]; then
+        echo "(I) Check Linux distribution: Moblin"
+        CopyUdevRule
+    fi
+    rm -f ${xfile}
+}
+
+CopyUdevRule() {
+    if [ -e ${rulepath}/${rulefile} ]; then
+        rm -f ${rulepath}/${rulefile}
+    fi
+    echo "(I) Copy udev rule: ${driverpath}/Rule/${rulefile} to ${rulepath}."
+    cp -f ${driverpath}/Rule/${rulefile} ${rulepath}
+}
+
+RemoveUdevRule() {
+    if [ -e ${rulepath}/${rulefile} ]; then
+        rm -f ${rulepath}/${rulefile}
+        echo "(I) Removed udev rule: ${rulepath}/${rulefile}."
+    fi
+}
+
 Add2Blacklist() {
     if [ -w ${blacklistpath} ]; then
         grep -q $1 ${blacklistpath}
@@ -292,10 +344,28 @@ Add2Blacklist() {
         if [ $? -eq 1 ]; then
             filelines=`cat ${blacklistpath3} | wc -l`
             echo "(I) Add kernel module $1 into ${blacklistpath3}."
-            sed -i ''${filelines}'a\# added by eGalax Touch installer\n'$1'' ${blacklistpath3}
+            sed -i ''${filelines}'a\# added by eGalax Touch installer\nblacklist '$1'' ${blacklistpath3}
         else
             echo "(I) The kernel module $1 has been added in ${blacklistpath3}."
         fi
+    elif [ -w ${blacklistpath4} ]; then
+        grep -q $1 ${blacklistpath4}
+        if [ $? -eq 1 ]; then
+            filelines=`cat ${blacklistpath4} | wc -l`
+            echo "(I) Add kernel module $1 into ${blacklistpath4}."
+            sed -i ''${filelines}'a\# added by eGalax Touch installer\nblacklist '$1'' ${blacklistpath4}
+        else
+            echo "(I) The kernel module $1 has been added in ${blacklistpath4}."
+        fi
+    elif [ -w ${blacklistpath5} ]; then
+        grep -q $1 ${blacklistpath5}
+        if [ $? -eq 1 ]; then
+            filelines=`cat ${blacklistpath5} | wc -l`
+            echo "(I) Add kernel module $1 into ${blacklistpath5}."
+            sed -i ''${filelines}'a\# added by eGalax Touch installer\n'$1'' ${blacklistpath5}
+        else
+            echo "(I) The kernel module $1 has been added in ${blacklistpath5}."
+        fi
     else
         echo "(I) No blacklist file found in /etc/modprobe.d or /etc/hotplug."
         if [ -w ${rclocalpath} ]; then
@@ -466,20 +536,56 @@ RestoreBlacklist() {
             fi
         fi
     elif [ -w ${blacklistpath3} ]; then
-        grep -q "usbtouchscreen" ${blacklistpath3}
+        grep -q "blacklist usbtouchscreen" ${blacklistpath3}
         if [ $? -eq 0 ]; then
             grep -q "# added by eGalax Touch installer" ${blacklistpath3}
             if [ $? -eq 0 ]; then
-                sed -i '/# added by eGalax Touch installer/,/usbtouchscreen/d' ${blacklistpath3}
-                echo "(I) Removed usbtouchscreen from ${blacklistpath3}."
+                sed -i '/# added by eGalax Touch installer/,/blacklist usbtouchscreen/d' ${blacklistpath3}
+                echo "(I) Removed blacklist usbtouchscreen from ${blacklistpath3}."
             fi
         else
-            grep -q "touchkitusb" ${blacklistpath3}
+            grep -q "blacklist touchkitusb" ${blacklistpath3}
             if [ $? -eq 0 ]; then
                 grep -q "# added by eGalax Touch installer" ${blacklistpath3}
                 if [ $? -eq 0 ]; then
-                    sed -i '/# added by eGalax Touch installer/,/touchkitusb/d' ${blacklistpath3}
-                    echo "(I) Removed touchkitusb from ${blacklistpath3}."
+                    sed -i '/# added by eGalax Touch installer/,/blacklist touchkitusb/d' ${blacklistpath3}
+                    echo "(I) Removed blacklist touchkitusb from ${blacklistpath3}."
+                fi
+            fi
+        fi
+    elif [ -w ${blacklistpath4} ]; then
+        grep -q "blacklist usbtouchscreen" ${blacklistpath4}
+        if [ $? -eq 0 ]; then
+            grep -q "# added by eGalax Touch installer" ${blacklistpath4}
+            if [ $? -eq 0 ]; then
+                sed -i '/# added by eGalax Touch installer/,/blacklist usbtouchscreen/d' ${blacklistpath4}
+                echo "(I) Removed blacklist usbtouchscreen from ${blacklistpath4}."
+            fi
+        else
+            grep -q "blacklist touchkitusb" ${blacklistpath4}
+            if [ $? -eq 0 ]; then
+                grep -q "# added by eGalax Touch installer" ${blacklistpath4}
+                if [ $? -eq 0 ]; then
+                    sed -i '/# added by eGalax Touch installer/,/blacklist touchkitusb/d' ${blacklistpath4}
+                    echo "(I) Removed blacklist touchkitusb from ${blacklistpath4}."
+                fi
+            fi
+        fi
+    elif [ -w ${blacklistpath5} ]; then
+        grep -q "usbtouchscreen" ${blacklistpath5}
+        if [ $? -eq 0 ]; then
+            grep -q "# added by eGalax Touch installer" ${blacklistpath5}
+            if [ $? -eq 0 ]; then
+                sed -i '/# added by eGalax Touch installer/,/usbtouchscreen/d' ${blacklistpath5}
+                echo "(I) Removed usbtouchscreen from ${blacklistpath5}."
+            fi
+        else
+            grep -q "touchkitusb" ${blacklistpath5}
+            if [ $? -eq 0 ]; then
+                grep -q "# added by eGalax Touch installer" ${blacklistpath5}
+                if [ $? -eq 0 ]; then
+                    sed -i '/# added by eGalax Touch installer/,/touchkitusb/d' ${blacklistpath5}
+                    echo "(I) Removed touchkitusb from ${blacklistpath5}."
                 fi
             fi
         fi
@@ -569,7 +675,7 @@ EndSection\
         if [ $? -eq 0 ]; then
             grep -q "Human Interface Device" ${usbfile}
             if [ $? -eq 0 ]; then
-                sed -i '/Option "ScreenNo"/a\        Option "SkipClick" "1"' $1
+                sed -i '/Option "ScreenNo"/a\        Option "SkipClick" "0"' $1 # 2010/03/26
             fi
         fi
     fi
@@ -645,6 +751,7 @@ if [ $# = 0 ]; then
     CheckOldDriver
     ExtractDriver
     CopyXorgMudule
+    CheckMoblin
     CheckInterface
     EditConfigFile
     echo ""
@@ -656,6 +763,7 @@ elif [ $# = 1 ]; then
         echo "(I) Begin to remove eGalax Touch driver."
         RemoveDriver
         RemoveXorgModule
+        RemoveUdevRule
         RestoreBlacklist
         RestoreConfigFile
         echo ""
